@@ -22,9 +22,6 @@ def test_flare_detection(plot = False):
 
     quality = np.full(10000, 0) #state all qualities are good
 
-
-    toffee.flatten(time, flux, flux_err)
-
     
     #define shape for the decay of a flare given from double exponential decay
     def dbl_exp_decay(x, start_time, alpha_0, beta_0, alpha_1, beta_1, C):
@@ -467,4 +464,165 @@ def test_end_to_end_cases(cases):
     
         test_end_to_end(A_1, omega_1, A_2, omega_2, quad)
 
-    print('Done!')
\ No newline at end of file
+    print('Done!')
+
+
+
+#Test whether ED is accurate within 5%
+def test_equivalent_duration():
+    np.random.seed(42)
+
+    #Let's make our fake orbit run over sector 1 of tess observation
+    orbit_1_start = 0
+    orbit_1_end = 10
+    
+    time = np.linspace(0, 10, 1001) #time across entire sector 1 times
+
+    flux = np.full(1001, 1) + np.random.normal(0, 10**-2, 1001)
+
+    flux_err = np.full(1001, 10**-2) #same as spread of points
+
+    quality = np.full(1001, 0)
+    
+    flux[300:310] = np.linspace(1, 10, 10) * -1 + 11
+
+    #triangle has height of 9 (when you subtract background) and length of 9*0.01 = 0.09, area of 0.405 (days)
+    true_area =  0.405 #days
+    true_area = true_area * 86400 #seconds
+
+    #run through TOFFEE
+
+    flare_characteristics = toffee.flare_finder(time, flux, flux_err, quality, detrend = False,
+                                                clip_breaks = 0, consecutive = True)
+    
+    measured_area = flare_characteristics[4][0]
+
+    #Test that it's accurate to within 5% error
+    assert np.isclose(true_area, measured_area, rtol = 0.05)
+
+    return 'Done!'
+
+
+
+def test_break_finder():
+
+    #create flat lightcurve with various breaks
+    time = np.linspace(0, 100, 1001) #time across entire sector 1 times
+
+    flux = np.full(1001, 1)
+
+    #Add a break 25 cadences wide, 2.5 days
+    break_mask_25 = ((time > time[100]) & (time < time[126])) == False
+
+    #Add a break 100 cadences wide, 10 days
+    break_mask_100 = ((time > time[200]) & (time < time[301])) == False
+
+    #Add a break 250 cadences wide, 25 days
+    break_mask_250 = ((time > time[500]) & (time < time[751])) == False
+
+    #Add breaks masks to lightcurve
+    time = time[break_mask_25 & break_mask_100 & break_mask_250]
+    flux = flux[break_mask_25 & break_mask_100 & break_mask_250]
+
+    #Run through break detector to only find break of 250 cadences
+    sector_break_frame = toffee.break_finder(time, flux, min_break = 25)
+
+    #Test the break is at the right place
+    true_break = np.array([375, 50.0, 75.1]) #recall we cut out 125 cadences before index 500 so it should start at 375
+    detected_break = np.array([sector_break_frame['Break_Index'],
+                               sector_break_frame['Break_Start_Time'],
+                               sector_break_frame['Break_End_Time']]).flatten()
+
+    np.testing.assert_array_almost_equal(detected_break,true_break) #Using almost equal due to some floating point error
+
+
+    #Run through break detector to find breaks of 250 cadences and 100 cadences
+    sector_break_frame = toffee.break_finder(time, flux, min_break = 10)
+
+    #Test the break is at the right place
+    true_break = np.array([175, 375, 20.0, 50.0, 30.1, 75.1])
+    detected_break = np.array([sector_break_frame['Break_Index'],
+                               sector_break_frame['Break_Start_Time'],
+                               sector_break_frame['Break_End_Time']]).flatten()
+
+    np.testing.assert_array_almost_equal(detected_break,true_break)
+
+
+    #Run through break detector to find all breaks
+    sector_break_frame = toffee.break_finder(time, flux, min_break = 2.5)
+
+    #Test the break is at the right place
+    true_break = np.array([100, 175, 375, 10.0, 20.0, 50.0, 12.6, 30.1, 75.1])
+    detected_break = np.array([sector_break_frame['Break_Index'],
+                               sector_break_frame['Break_Start_Time'],
+                               sector_break_frame['Break_End_Time']]).flatten()
+
+    np.testing.assert_array_almost_equal(detected_break,true_break)
+
+
+    return 'Done!'
+
+
+
+
+def test_break_masking():
+
+    #create flat lightcurve with various breaks
+    time = np.linspace(0, 100, 1001) #time across entire sector 1 times
+
+    flux = np.full(1001, 1)
+
+    #Add a break 25 cadences wide, 2.5 days
+    break_mask_25 = ((time > time[100]) & (time < time[126])) == False
+
+    #Add a break 100 cadences wide, 10 days
+    break_mask_100 = ((time > time[200]) & (time < time[301])) == False
+
+    #Add a break 250 cadences wide, 25 days
+    break_mask_250 = ((time > time[500]) & (time < time[751])) == False
+
+    #Add breaks masks to lightcurve
+    time = time[break_mask_25 & break_mask_100 & break_mask_250]
+    flux = flux[break_mask_25 & break_mask_100 & break_mask_250]
+
+    #For simplicity we'll only clip 10 points
+
+    #Run through break detector to only find break of 250 cadences 
+    detected_mask = toffee.light_curve_mask(time, flux, min_break = 25, clip_breaks = 10)
+
+    #For true mask 10 indices left of index 375 and 10 right of 375 and first and last 10 cadences
+    #Avoiding an off by one error
+    true_mask_break = ((time > time[364]) & (time < time[385])) == False
+    true_mask_start = time > time[9]
+    true_mask_end = time < time[616]
+    true_mask = true_mask_break & true_mask_start & true_mask_end
+    np.testing.assert_array_equal(detected_mask,true_mask)
+
+    
+    #Run through break detector to only find break of 100 cadences 
+    detected_mask = toffee.light_curve_mask(time, flux, min_break = 10, clip_breaks = 10)
+
+    true_mask_break_100 = ((time > time[164]) & (time < time[185])) == False
+    true_mask_break_250 = ((time > time[364]) & (time < time[385])) == False
+    true_mask_start = time > time[9]
+    true_mask_end = time < time[616]
+
+    true_mask = true_mask_break_100 & true_mask_break_250 & true_mask_start & true_mask_end
+
+    np.testing.assert_array_equal(detected_mask,true_mask)
+
+
+    #Run through break detector to only find break of 100 cadences 
+    detected_mask = toffee.light_curve_mask(time, flux, min_break = 2.5, clip_breaks = 10)
+    
+    true_mask_break_25 = ((time > time[89]) & (time < time[110])) == False
+    true_mask_break_100 = ((time > time[164]) & (time < time[185])) == False
+    true_mask_break_250 = ((time > time[364]) & (time < time[385])) == False
+    true_mask_start = time > time[9]
+    true_mask_end = time < time[616]
+
+    true_mask = true_mask_break_25 & true_mask_break_100 & true_mask_break_250 & true_mask_start & true_mask_end
+
+    np.testing.assert_array_equal(detected_mask,true_mask)
+
+    return 'Done!'
\ No newline at end of file
